require 'test_helper'

describe Vector do
  describe '#initialize' do
    it 'should store vector coordinates in attributes' do
      vector = Vector.new(1, 5, 8)
      _(vector.axis_x).must_equal 1
      _(vector.axis_y).must_equal 5
      _(vector.axis_z).must_equal 8
    end
  end

  describe '.from_points' do
    it 'should create vector instance' do
      vector = Vector.from_points([1, 2, 3], [6, 8, 9])
      _(vector.class).must_equal Vector
    end

    it 'should fill vector coordinates based on passed points' do
      vector = Vector.from_points([1, 1, 1], [1, 2, 3])
      _(vector.axis_x).must_equal 0
      _(vector.axis_y).must_equal 1
      _(vector.axis_z).must_equal 2
    end
  end

  describe '#to_s' do
    it 'should pretty print the vector' do
      vector = Vector.new(5, 6, 8)
      _(vector.to_s).must_equal "(5, 6, 8)"
    end
  end

  describe '#==' do
    it 'should correctly check for equality' do
      vector_one = Vector.new(1, 2, 3)
      vector_two = Vector.new(1, 2, 3)
      _(vector_one).must_equal vector_two
    end

    it 'should say that different vectors differ' do
      vector_one = Vector.new(5, 6, 8)
      vector_two = Vector.new(7, 6, 7)
      _(vector_one).wont_equal vector_two
    end
  end

  describe '#sum' do
    [{first: Vector.new(1, 1, 1),
      second: Vector.new(0, 5, 8),
      sum: Vector.new(1, 6, 9)
     },{
       first: Vector.new(1, 2, 3),
       second: Vector.new(5, 6, 8),
       sum: Vector.new(6, 8, 11)
     }].each do |test|
      it 'should create new vector when summing them up' do
         _(test[:first].sum(test[:second])).must_equal test[:sum]
      end
    end
  end

  describe '#scal_mult' do
    it 'should calculate scalar multiplication of vectors' do
      first = Vector.new(1, 2, 3)
      second = Vector.new(5, 6, 8)
      _(first.scal_mult(second)).must_equal 41
    end
  end

  describe '#module' do
    it 'should calculate module of the vector' do
      vector = Vector.new(0, 3, 4)
      _(vector.module).must_equal 5
    end
  end


end
